Learn R Programming

SticsRFiles (version 1.7.0)

approx_vapour_pressure: Approximate vapour pressure

Description

Approximates vapour pressure as the saturated vapour pressure at the daily mean air temperature using relative humidity. See section 9.3 of the STICS book, as well as M. Launay's explanations on the STICS forum (link).

Usage

approx_vapour_pressure(mean_temp, rel_humid)

Value

numeric vector

Arguments

mean_temp

numeric vector of daily mean air temperature (in Celsius degrees)

rel_humid

numeric vector of relative humidity (in percentage)

Author

Timothee Flutre

Examples

Run this code
approx_vapour_pressure(15, 60)

Run the code above in your browser using DataLab