download_usm_csv: Downloading a CSV usms data file example into a directory
Description
The file is an example that can be used for generating JavaSTICS
usms.xml input file from parameters values stored in a CSV file using
the function gen_usms_xml
Usage
download_usm_csv(
file = NULL,
out_dir = tempdir(),
stics_version = "latest",
overwrite = FALSE,
verbose = FALSE
)
Value
A vector of copied files path.
Arguments
- file
Name of a csv file (optional, not used for the moment)
- out_dir
Directory path where to copy the csv file
(default: tempdir())
- stics_version
Name of the STICS version. Optional, by default
the latest version returned by get_stics_versions_compat() is used.
- overwrite
Optional logical, TRUE for overwriting files,
FALSE otherwise (default)
- verbose
Logical value for displaying information while running