Extract an XML JavaSTICS workspace from a source workspace

extract_workspace(
  from_workspace,
  to_workspace,
  javastics,
  usm = NULL,
  use_mod_files = FALSE
)

Arguments

from_workspace

Source workspace path

to_workspace

Target workspace path

javastics

JavaSTICS directory path, needed for getting plant files which are stored in JavaSTICS plant directory, or general parameters files and *.mod files from the config directory

usm

vector of situation names (i.e. USMs to extract.)

use_mod_files

Logical: if TRUE, *.mod files are searched in the from_workspace and copied to the to_workspace if found. Default is FALSE.

Value

None

Examples

if (FALSE) { # \dontrun{
# Extract all usms from a source workspace to a target workspace
extract_workspace(
  "/path/to/source/workspace",
  "/path/to/target/workspace",
  "/path/to/javastics/dir"
)

# Extract only selected usms from a source workspace to a target workspace
extract_workspace("/path/to/source/workspace",
  "/path/to/target/workspace",
  "/path/to/javastics/dir",
  usm = c("SugarCane", "potato")
)
} # }