Learn R Programming

SticsRFiles (version 1.7.0)

get_examples_path: Getting examples files path attached to a STICS version for a given file type

Description

Getting examples files path attached to a STICS version for a given file type

Usage

get_examples_path(file_type, stics_version = "latest", overwrite = FALSE)

Value

A directory path for examples files for given file type and STICS version or a vector of (for unknown file types "" is returned as path)

Arguments

file_type

A file type string among files types or a vector of ("csv", "obs", "sti", "txt", "xml")

stics_version

Name of the STICS version. Optional, by default the latest version returned by get_stics_versions_compat() is used.

overwrite

TRUE for overwriting directory; FALSE otherwise

Examples

Run this code
get_examples_path(file_type = "csv")

get_examples_path(file_type = c("csv", "sti"))

get_examples_path(file_type = "csv", stics_version = "V8.5")

Run the code above in your browser using DataLab