Extracts the soil names from a USMs file, or from a soil file
get_soils_list(file, soil = NULL)A vector of soil names
The file given as the file_path is either a "usms" file type
to get all the soils used in a particular USM, or a soil file type ("sols")
to get all soil types available in a soil file.
path <- get_examples_path(file_type = "xml")
# Read from a usms file (soils used in a USM):
soil_list <- get_soils_list(file = file.path(path, "usms.xml"))
# Read from a soil file (all soil types available in a soil file)
soil_list <- get_soils_list(file = file.path(path, "sols.xml"))
soil_list <- get_soils_list(
file = file.path(path, "usms.xml"),
soil = c("solcanne", "sole")
)