Upgrade a Javastics STICS xml workspace directory to a next major version

upgrade_workspace_xml(
  workspace,
  out_dir,
  ...,
  javastics = NULL,
  overwrite = FALSE,
  verbose = FALSE
)

Arguments

workspace

JavaStics xml workspace path

out_dir

Output directory path

...

additional argument(s) to pass to called functions

javastics

Path of JavaSTICS containing the STICS version corresponding to the version of the files to be converted (optional)

overwrite

Logical TRUE for overwriting files, FALSE otherwise (default)

verbose

logical, TRUE for displaying a copy message FALSE otherwise (default)

Value

None

Examples

if (FALSE) { # \dontrun{
upgrade_workspace_xml(
  workspace = "/path/to/JavaSTICS/workspace",
  out_dir = "/path/to/an/output/directory",
  javastics = "/path/to/JavaSTICS/folder"
)
} # }