R/extract_workspace.R
extract_workspace.RdExtract an XML JavaSTICS workspace from a source workspace
extract_workspace(
from_workspace,
to_workspace,
javastics,
usm = NULL,
use_mod_files = FALSE
)Source workspace path
Target workspace path
JavaSTICS directory path, needed for getting
plant files which are stored in JavaSTICS plant directory, or general
parameters files and *.mod files from the config directory
vector of situation names (i.e. USMs to extract.)
Logical: if TRUE, *.mod files are searched in the from_workspace and copied to the to_workspace if found. Default is FALSE.
None
if (FALSE) { # \dontrun{
# Extract all usms from a source workspace to a target workspace
extract_workspace(
"/path/to/source/workspace",
"/path/to/target/workspace",
"/path/to/javastics/dir"
)
# Extract only selected usms from a source workspace to a target workspace
extract_workspace("/path/to/source/workspace",
"/path/to/target/workspace",
"/path/to/javastics/dir",
usm = c("SugarCane", "potato")
)
} # }