Please see get_stics_versions_compat() for the full list of
STICS versions that can be used for the
argument stics_version.
param_df is a data.frame with the following format:
| Tec_name | julres_1 | coderes_1 |
| USM_2017_T1_CI_tec.xml | NA | 1 |
| BIN_CANPC_05_SEC_220-0-0_34K_CANPC05T3_Q_tec.xml | 110 | 1 |
| BIN_AGT_04_IRR_220-0-0_33K_AGT04T2_Q_tec.xml | 73 | 1 |
| AGA_ARB_13_IRR_220-0-0_37K_ARB13_C_tec.xml | 82 | 1 |
| AGA_ARB_13_SEC_220-0-0_37K_ARB13_C_tec.xml | 82 | 1 |
| FRA_ARB_11_SEC_220-0-0_38K_E_tec.xml | 70 | 1 |
| MAG_ARB_09_SEC_220-0-0_38K_E_tec.xml | 81 | 1 |
| MAG_ARV_12_IRR_220-0-0_36K_ARV12_C_tec.xml | 100 | 1 |
| MAG_ARV_12_SEC_220-0-0_36K_ARV12_C_tec.xml | 100 | 1 |
| FRA_ARB_12_SEC_220-0-0_31K_ARB12_C_tec.xml | 92 | 1 |
| FRA_ARB_13_SEC_220-0-0_37K_ARB13_C_tec.xml | 82 | 1 |
The first column gives the tec file name (to be generated), all following
columns give the parameter value to put in the file, and each line denotes a
separate tec file (for e.g. several USMs).
The first column name must contain the keyword tec or Tec or TEC as
a prefix to be detected (as shown in the table extract above).
If not given (the default, NULL), the function returns the template as is.