powered by
Getting examples files path attached to a STICS version for a given file type
get_examples_path(file_type, stics_version = "latest", overwrite = FALSE)
A directory path for examples files for given file type and STICS version or a vector of (for unknown file types "" is returned as path)
A file type string among files types or a vector of ("csv", "obs", "sti", "txt", "xml")
Name of the STICS version. Optional, by default the latest version returned by get_stics_versions_compat() is used.
get_stics_versions_compat()
TRUE for overwriting directory; FALSE otherwise
get_examples_path(file_type = "csv") get_examples_path(file_type = c("csv", "sti")) get_examples_path(file_type = "csv", stics_version = "V8.5")
Run the code above in your browser using DataLab