R/upgrade_xml_files.R
upgrade_workspace_xml.RdUpgrade a Javastics STICS xml workspace directory to a next major version
upgrade_workspace_xml(
workspace,
out_dir,
...,
javastics = NULL,
overwrite = FALSE,
verbose = FALSE
)JavaStics xml workspace path
Output directory path
additional argument(s) to pass to called functions
Path of JavaSTICS containing the STICS version corresponding to the version of the files to be converted (optional)
Logical TRUE for overwriting files, FALSE otherwise (default)
logical, TRUE for displaying a copy message FALSE otherwise (default)
None
if (FALSE) { # \dontrun{
upgrade_workspace_xml(
workspace = "/path/to/JavaSTICS/workspace",
out_dir = "/path/to/an/output/directory",
javastics = "/path/to/JavaSTICS/folder"
)
} # }