Learn R Programming

SticsRFiles (version 1.7.0)

upgrade_workspace_xml: Upgrade a Javastics STICS xml workspace directory to a next major version

Description

Upgrade a Javastics STICS xml workspace directory to a next major version

Usage

upgrade_workspace_xml(
  workspace,
  out_dir,
  ...,
  javastics = NULL,
  overwrite = FALSE,
  verbose = FALSE
)

Value

None

Arguments

workspace

JavaStics xml workspace path

out_dir

Output directory path

...

additional argument(s) to pass to called functions

javastics

Path of JavaSTICS containing the STICS version corresponding to the version of the files to be converted (optional)

overwrite

Logical TRUE for overwriting files, FALSE otherwise (default)

verbose

logical, TRUE for displaying a copy message FALSE otherwise (default)

Examples

Run this code
if (FALSE) {
upgrade_workspace_xml(
  workspace = "/path/to/JavaSTICS/workspace",
  out_dir = "/path/to/an/output/directory",
  javastics = "/path/to/JavaSTICS/folder"
)
}

Run the code above in your browser using DataLab